bayespy.inference.vmp.nodes.expfamily.ExponentialFamilyDistribution.plates_to_parent
====================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. automethod:: ExponentialFamilyDistribution.plates_to_parent